@@ -1,4 +1,4 @@
-from core import get_sas_connect
+from .core import get_sas_connect
 
 
 class SASMA():
